@@ -1,7 +1,7 @@
 """
 Type annotations for route53 service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53/literals.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_route53/literals/)
 
 Usage::
 
@@ -23,12 +23,16 @@ __all__ = (
     "AccountLimitTypeType",
     "ChangeActionType",
     "ChangeStatusType",
+    "CidrCollectionChangeActionType",
     "CloudWatchRegionType",
     "ComparisonOperatorType",
     "HealthCheckRegionType",
     "HealthCheckTypeType",
     "HostedZoneLimitTypeType",
     "InsufficientDataHealthStatusType",
+    "ListCidrBlocksPaginatorName",
+    "ListCidrCollectionsPaginatorName",
+    "ListCidrLocationsPaginatorName",
     "ListHealthChecksPaginatorName",
     "ListHostedZonesPaginatorName",
     "ListQueryLoggingConfigsPaginatorName",
@@ -43,7 +47,9 @@ __all__ = (
     "StatisticType",
     "TagResourceTypeType",
     "VPCRegionType",
+    "Route53ServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
     "WaiterName",
 )
@@ -58,6 +64,7 @@ AccountLimitTypeType = Literal[
 ]
 ChangeActionType = Literal["CREATE", "DELETE", "UPSERT"]
 ChangeStatusType = Literal["INSYNC", "PENDING"]
+CidrCollectionChangeActionType = Literal["DELETE_IF_EXISTS", "PUT"]
 CloudWatchRegionType = Literal[
     "af-south-1",
     "ap-east-1",
@@ -67,6 +74,7 @@ CloudWatchRegionType = Literal[
     "ap-south-1",
     "ap-southeast-1",
     "ap-southeast-2",
+    "ap-southeast-3",
     "ca-central-1",
     "cn-north-1",
     "cn-northwest-1",
@@ -83,6 +91,7 @@ CloudWatchRegionType = Literal[
     "us-gov-east-1",
     "us-gov-west-1",
     "us-iso-east-1",
+    "us-iso-west-1",
     "us-isob-east-1",
     "us-west-1",
     "us-west-2",
@@ -115,6 +124,9 @@ HealthCheckTypeType = Literal[
 ]
 HostedZoneLimitTypeType = Literal["MAX_RRSETS_BY_ZONE", "MAX_VPCS_ASSOCIATED_BY_ZONE"]
 InsufficientDataHealthStatusType = Literal["Healthy", "LastKnownStatus", "Unhealthy"]
+ListCidrBlocksPaginatorName = Literal["list_cidr_blocks"]
+ListCidrCollectionsPaginatorName = Literal["list_cidr_collections"]
+ListCidrLocationsPaginatorName = Literal["list_cidr_locations"]
 ListHealthChecksPaginatorName = Literal["list_health_checks"]
 ListHostedZonesPaginatorName = Literal["list_hosted_zones"]
 ListQueryLoggingConfigsPaginatorName = Literal["list_query_logging_configs"]
@@ -136,6 +148,7 @@ ResourceRecordSetRegionType = Literal[
     "ap-south-1",
     "ap-southeast-1",
     "ap-southeast-2",
+    "ap-southeast-3",
     "ca-central-1",
     "cn-north-1",
     "cn-northwest-1",
@@ -165,6 +178,7 @@ VPCRegionType = Literal[
     "ap-south-1",
     "ap-southeast-1",
     "ap-southeast-2",
+    "ap-southeast-3",
     "ca-central-1",
     "cn-north-1",
     "eu-central-1",
@@ -180,10 +194,12 @@ VPCRegionType = Literal[
     "us-gov-east-1",
     "us-gov-west-1",
     "us-iso-east-1",
+    "us-iso-west-1",
     "us-isob-east-1",
     "us-west-1",
     "us-west-2",
 ]
+Route53ServiceName = Literal["route53"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -193,10 +209,12 @@ ServiceName = Literal[
     "amp",
     "amplify",
     "amplifybackend",
+    "amplifyuibuilder",
     "apigateway",
     "apigatewaymanagementapi",
     "apigatewayv2",
     "appconfig",
+    "appconfigdata",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -211,12 +229,16 @@ ServiceName = Literal[
     "autoscaling",
     "autoscaling-plans",
     "backup",
+    "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-media-pipelines",
+    "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
     "cloudcontrol",
@@ -264,6 +286,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "drs",
     "ds",
     "dynamodb",
     "dynamodbstreams",
@@ -283,8 +306,10 @@ ServiceName = Literal[
     "elbv2",
     "emr",
     "emr-containers",
+    "emr-serverless",
     "es",
     "events",
+    "evidently",
     "finspace",
     "finspace-data",
     "firehose",
@@ -295,6 +320,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -311,6 +337,7 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector2",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -324,11 +351,14 @@ ServiceName = Literal[
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
+    "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivschat",
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -369,7 +399,9 @@ ServiceName = Literal[
     "meteringmarketplace",
     "mgh",
     "mgn",
+    "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhubstrategy",
     "mobile",
     "mq",
     "mturk",
@@ -391,6 +423,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
@@ -398,11 +431,13 @@ ServiceName = Literal[
     "qldb-session",
     "quicksight",
     "ram",
+    "rbin",
     "rds",
     "rds-data",
     "redshift",
     "redshift-data",
     "rekognition",
+    "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -412,6 +447,7 @@ ServiceName = Literal[
     "route53-recovery-readiness",
     "route53domains",
     "route53resolver",
+    "rum",
     "s3",
     "s3control",
     "s3outposts",
@@ -469,9 +505,25 @@ ServiceName = Literal[
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
+    "list_cidr_blocks",
+    "list_cidr_collections",
+    "list_cidr_locations",
     "list_health_checks",
     "list_hosted_zones",
     "list_query_logging_configs",
